pub enum FieldChannel {
SurfacePresence,
OccupancyPresence,
}Expand description
Which channel of a cell contributes to a planar mask.
Variants
SurfacePresence
A cell is set when it holds at least one surface crossing.
OccupancyPresence
A cell is set when it holds at least one occupancy span.